==> haskell-random-shuffle-0.0.4-270-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-random-shuffle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 random-shuffle
version:              0.0.4
visibility:           public
id:                   random-shuffle-0.0.4-AgzkR1G9Cs15wq6PasKg2P
key:                  random-shuffle-0.0.4-AgzkR1G9Cs15wq6PasKg2P
license:              BSD-3-Clause
copyright:
    Oleg Kiselyov 2001
    Manlio Perillo 2009

maintainer:           Manlio Perillo <manlio.perillo@gmail.com>
author:               Oleg Kiselyov, Manlio Perillo, Andras Slemmer
stability:            Beta
synopsis:             Random shuffle implementation.
description:
    Random shuffle implementation, on immutable lists.
    Based on `perfect shuffle'\'' implementation by Oleg Kiselyov,
    available on http://okmij.org/ftp/Haskell/perfect-shuffle.txt

category:             System
abi:                  905a21166bf73228cf2934cee9ff557d
exposed:              True
exposed-modules:      System.Random.Shuffle
import-dirs:          /usr/lib/ghc-9.4.8/site-local/random-shuffle-0.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/random-shuffle-0.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/random-shuffle-0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-random-shuffle
hs-libraries:         HSrandom-shuffle-0.0.4-AgzkR1G9Cs15wq6PasKg2P
depends:
    MonadRandom-0.6.2-FSdl4cUdgmaCCuUKrDBd9l base-4.17.2.1
    random-1.2.1.3-6VZLKqOL0AYAmXOMJWUGdj

haddock-interfaces:
    /usr/share/doc/haskell-random-shuffle/html/random-shuffle.haddock

haddock-html:         /usr/share/doc/haskell-random-shuffle/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-random-shuffle-0.0.4-271-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-random-shuffle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 random-shuffle
version:              0.0.4
visibility:           public
id:                   random-shuffle-0.0.4-DsZ1Fcn4DGdHD9Y46F2gTE
key:                  random-shuffle-0.0.4-DsZ1Fcn4DGdHD9Y46F2gTE
license:              BSD-3-Clause
copyright:
    Oleg Kiselyov 2001
    Manlio Perillo 2009

maintainer:           Manlio Perillo <manlio.perillo@gmail.com>
author:               Oleg Kiselyov, Manlio Perillo, Andras Slemmer
stability:            Beta
synopsis:             Random shuffle implementation.
description:
    Random shuffle implementation, on immutable lists.
    Based on `perfect shuffle'\'' implementation by Oleg Kiselyov,
    available on http://okmij.org/ftp/Haskell/perfect-shuffle.txt

category:             System
abi:                  da2a1f6c045878772a85c1977186c1fa
exposed:              True
exposed-modules:      System.Random.Shuffle
import-dirs:          /usr/lib/ghc-9.4.8/site-local/random-shuffle-0.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/random-shuffle-0.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/random-shuffle-0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-random-shuffle
hs-libraries:         HSrandom-shuffle-0.0.4-DsZ1Fcn4DGdHD9Y46F2gTE
depends:
    MonadRandom-0.6.2-9GpBUnqkgbLHrscg3IURPi base-4.17.2.1
    random-1.2.1.3-HJyMSutqwH8Lt2zSK2VrDO

haddock-interfaces:
    /usr/share/doc/haskell-random-shuffle/html/random-shuffle.haddock

haddock-html:         /usr/share/doc/haskell-random-shuffle/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
